==> sil-machine-0.3.2.tar.gz: sil-machine-0.3.2/machine/corpora/__init__.py <==
from .aligned_word_pair import AlignedWordPair
from .dbl_bundle_text import DblBundleText
from .dbl_bundle_text_corpus import DblBundleTextCorpus
from .dictionary_text_alignment_corpus import DictionaryTextAlignmentCorpus
from .dictionary_text_corpus import DictionaryTextCorpus
from .filtered_text import FilteredText
from .filtered_text_alignment_corpus import FilteredTextAlignmentCorpus
from .filtered_text_corpus import FilteredTextCorpus
from .memory_text import MemoryText
from .memory_text_alignment_collection import MemoryTextAlignmentCollection
from .null_text import NullText
from .null_text_alignment_collection import NullTextAlignmentCollection
from .parallel_text import ParallelText
from .parallel_text_corpus import ParallelTextCorpus
from .parallel_text_segment import ParallelTextSegment
from .paratext_text_corpus import ParatextTextCorpus
from .text import Text
from .text_alignment import TextAlignment
from .text_alignment_collection import TextAlignmentCollection
from .text_alignment_corpus import TextAlignmentCorpus
from .text_corpus import TextCorpus
from .text_file_text import TextFileText
from .text_file_text_alignment_collection import TextFileTextAlignmentCollection
from .text_file_text_alignment_corpus import TextFileTextAlignmentCorpus
from .text_file_text_corpus import TextFileTextCorpus
from .text_segment import TextSegment
from .text_segment_ref import TextSegmentRef
from .token_processors import (
    ESCAPE_SPACES,
    LOWERCASE,
    NFC_NORMALIZE,
    NFD_NORMALIZE,
    NFKC_NORMALIZE,
    NFKD_NORMALIZE,
    NO_OP,
    UNESCAPE_SPACES,
    EscapeSpacesTokenProcessor,
    LowercaseTokenProcessor,
    NoOpTokenProcessor,
    NormalizeTokenProcessor,
    PipelineTokenProcessor,
    TokenProcessor,
    UnescapeSpacesTokenProcessor,
    pipeline,
)
from .usfm_file_text import UsfmFileText
from .usfm_file_text_corpus import UsfmFileTextCorpus
from .usfm_marker import UsfmJustification, UsfmMarker, UsfmStyleType, UsfmTextProperties, UsfmTextType
from .usfm_stylesheet import UsfmStylesheet
from .usx_file_text import UsxFileText
from .usx_file_text_alignment_collection import UsxFileTextAlignmentCollection
from .usx_file_text_alignment_corpus import UsxFileTextAlignmentCorpus
from .usx_file_text_corpus import UsxFileTextCorpus

__all__ = [
    "AlignedWordPair",
    "DblBundleText",
    "DblBundleTextCorpus",
    "DictionaryTextAlignmentCorpus",
    "DictionaryTextCorpus",
    "ESCAPE_SPACES",
    "EscapeSpacesTokenProcessor",
    "FilteredText",
    "FilteredTextAlignmentCorpus",
    "FilteredTextCorpus",
    "LOWERCASE",
    "LowercaseTokenProcessor",
    "MemoryText",
    "MemoryTextAlignmentCollection",
    "NFC_NORMALIZE",
    "NFD_NORMALIZE",
    "NFKC_NORMALIZE",
    "NFKD_NORMALIZE",
    "NO_OP",
    "NoOpTokenProcessor",
    "NormalizeTokenProcessor",
    "NullText",
    "NullTextAlignmentCollection",
    "ParallelText",
    "ParallelTextCorpus",
    "ParallelTextSegment",
    "ParatextTextCorpus",
    "PipelineTokenProcessor",
    "Text",
    "TextAlignment",
    "TextAlignmentCollection",
    "TextAlignmentCorpus",
    "TextCorpus",
    "TextFileText",
    "TextFileTextAlignmentCollection",
    "TextFileTextAlignmentCorpus",
    "TextFileTextCorpus",
    "TextSegment",
    "TextSegmentRef",
    "TokenProcessor",
    "UNESCAPE_SPACES",
    "UnescapeSpacesTokenProcessor",
    "UsfmFileText",
    "UsfmFileTextCorpus",
    "UsfmJustification",
    "UsfmMarker",
    "UsfmStyleType",
    "UsfmStylesheet",
    "UsfmTextProperties",
    "UsfmTextType",
    "UsxFileText",
    "UsxFileTextAlignmentCollection",
    "UsxFileTextAlignmentCorpus",
    "UsxFileTextCorpus",
    "pipeline",
]

==> sil-machine-0.4.1.tar.gz: sil-machine-0.4.1/machine/corpora/__init__.py <==
from .aligned_word_pair import AlignedWordPair
from .dbl_bundle_text import DblBundleText
from .dbl_bundle_text_corpus import DblBundleTextCorpus
from .dictionary_text_alignment_corpus import DictionaryTextAlignmentCorpus
from .dictionary_text_corpus import DictionaryTextCorpus
from .filtered_text_alignment_corpus import FilteredTextAlignmentCorpus
from .filtered_text_corpus import FilteredTextCorpus
from .memory_text import MemoryText
from .memory_text_alignment_collection import MemoryTextAlignmentCollection
from .null_scripture_text import NullScriptureText
from .null_text import NullText
from .null_text_alignment_collection import NullTextAlignmentCollection
from .parallel_text import ParallelText
from .parallel_text_corpus import ParallelTextCorpus
from .parallel_text_segment import ParallelTextSegment
from .paratext_text_corpus import ParatextTextCorpus
from .text import Text
from .text_alignment import TextAlignment
from .text_alignment_collection import TextAlignmentCollection
from .text_alignment_corpus import TextAlignmentCorpus
from .text_corpus import TextCorpus
from .text_file_text import TextFileText
from .text_file_text_alignment_collection import TextFileTextAlignmentCollection
from .text_file_text_alignment_corpus import TextFileTextAlignmentCorpus
from .text_file_text_corpus import TextFileTextCorpus
from .text_segment import TextSegment
from .text_segment_ref import TextSegmentRef
from .token_processors import (
    ESCAPE_SPACES,
    LOWERCASE,
    NFC_NORMALIZE,
    NFD_NORMALIZE,
    NFKC_NORMALIZE,
    NFKD_NORMALIZE,
    NO_OP,
    UNESCAPE_SPACES,
    EscapeSpacesTokenProcessor,
    LowercaseTokenProcessor,
    NoOpTokenProcessor,
    NormalizeTokenProcessor,
    PipelineTokenProcessor,
    TokenProcessor,
    UnescapeSpacesTokenProcessor,
    pipeline,
)
from .usfm_file_text import UsfmFileText
from .usfm_file_text_corpus import UsfmFileTextCorpus
from .usfm_marker import UsfmJustification, UsfmMarker, UsfmStyleType, UsfmTextProperties, UsfmTextType
from .usfm_stylesheet import UsfmStylesheet
from .usx_file_text import UsxFileText
from .usx_file_text_alignment_collection import UsxFileTextAlignmentCollection
from .usx_file_text_alignment_corpus import UsxFileTextAlignmentCorpus
from .usx_file_text_corpus import UsxFileTextCorpus

__all__ = [
    "AlignedWordPair",
    "DblBundleText",
    "DblBundleTextCorpus",
    "DictionaryTextAlignmentCorpus",
    "DictionaryTextCorpus",
    "ESCAPE_SPACES",
    "EscapeSpacesTokenProcessor",
    "FilteredTextAlignmentCorpus",
    "FilteredTextCorpus",
    "LOWERCASE",
    "LowercaseTokenProcessor",
    "MemoryText",
    "MemoryTextAlignmentCollection",
    "NFC_NORMALIZE",
    "NFD_NORMALIZE",
    "NFKC_NORMALIZE",
    "NFKD_NORMALIZE",
    "NO_OP",
    "NoOpTokenProcessor",
    "NormalizeTokenProcessor",
    "NullScriptureText",
    "NullText",
    "NullTextAlignmentCollection",
    "ParallelText",
    "ParallelTextCorpus",
    "ParallelTextSegment",
    "ParatextTextCorpus",
    "PipelineTokenProcessor",
    "Text",
    "TextAlignment",
    "TextAlignmentCollection",
    "TextAlignmentCorpus",
    "TextCorpus",
    "TextFileText",
    "TextFileTextAlignmentCollection",
    "TextFileTextAlignmentCorpus",
    "TextFileTextCorpus",
    "TextSegment",
    "TextSegmentRef",
    "TokenProcessor",
    "UNESCAPE_SPACES",
    "UnescapeSpacesTokenProcessor",
    "UsfmFileText",
    "UsfmFileTextCorpus",
    "UsfmJustification",
    "UsfmMarker",
    "UsfmStyleType",
    "UsfmStylesheet",
    "UsfmTextProperties",
    "UsfmTextType",
    "UsxFileText",
    "UsxFileTextAlignmentCollection",
    "UsxFileTextAlignmentCorpus",
    "UsxFileTextCorpus",
    "pipeline",
]
